%global pypi_name tpm2-pytss
%global _name tpm2_pytss

Name:           python-%{pypi_name}
Version:        2.2.1
Release:        %mkrel 1
Summary:        TPM 2.0 TSS Bindings for Python

Group:          Development/Python

License:        BSD-2-Clause
URL:            https://github.com/tpm2-software/tpm2-pytss
Source:         %{pypi_source %{pypi_name}}

BuildRequires:  pyproject-rpm-macros
BuildRequires:  python3-asn1crypto
BuildRequires:  python3-cffi
BuildRequires:  python3-cryptography
BuildRequires:  python3-devel
BuildRequires:  python3-pytest
BuildRequires:  python3-pytest-xdist
BuildRequires:  python3-yaml
BuildRequires:  tpm2-tss-devel >= 2.0.0
BuildRequires:  python3dist(packaging)
BuildRequires:  python3dist(pip) >= 19
BuildRequires:  python3dist(pkgconfig)
BuildRequires:  python3dist(pycparser)
BuildRequires:  python3dist(setuptools) >= 44
BuildRequires:  python3dist(setuptools-scm) >= 3.4.3
BuildRequires:  python3dist(setuptools-scm[toml]) >= 3.4.3
BuildRequires:  python3dist(wheel)
BuildRequires:  gcc
# for tests
BuildRequires:  python3-pytest
BuildRequires:  python3-pytest-forked
BuildRequires:  python3-pytest-xdist
BuildRequires:  swtpm
BuildRequires:  tpm2-tools

%global _description %{expand:
TPM2 TSS Python bindings for Enhanced System API (ESYS), Feature API (FAPI),
Marshaling (MU), TCTI Loader (TCTILdr) and RC Decoding (rcdecode) libraries.
It also contains utility methods for wrapping keys to TPM 2.0 data structures
for importation into the TPM, unwrapping keys and exporting them from the TPM,
TPM-less makecredential command and name calculations, TSS2 PEM Key format
support, importing Keys from PEM, DER and SSH formats, conversion from
tpm2-tools based command line strings and loading tpm2-tools context files.
}

%description %{_description}

%package -n     python3-%{pypi_name}
Summary:        %{summary}

%description -n python3-%{pypi_name} %{_description}

%prep
%autosetup -p1 -n %{pypi_name}-%{version}

%generate_buildrequires
%pyproject_buildrequires


%build
%pyproject_wheel


%install
%pyproject_install

%pyproject_save_files %{_name}


%check
%pyproject_check_import
# tests are very dependent on the python/openssl versions and fail at various places
# The test test_tools_decode_tpms_nv_public fails on Fedora rawhide now
%pytest --import-mode=append -k "not test_tools_decode_tpms_nv_public" -n %{_smp_build_ncpus} || :


%files -n python3-%{pypi_name} -f %{pyproject_files}
%doc README.md




%changelog
* Sat Mar 09 2024 daviddavid <daviddavid> 2.2.1-1.mga10
+ Revision: 2048819
- new version: 2.2.1

* Fri Dec 22 2023 tv <tv> 1.2.0-3.mga10
+ Revision: 2020853
- Rebuild for python 3.12

* Thu Mar 09 2023 daviddavid <daviddavid> 1.2.0-2.mga9
+ Revision: 1948442
- rebuild for new cryptography

* Tue Dec 13 2022 tv <tv> 1.2.0-1.mga9
+ Revision: 1921639
- Ignore testsuite failures for now
- imported package python-tpm2-pytss


* Mon Dec 12 2022 Thierry Vignaud <tv@mageia.org> 1.2.0-1.mga9
- Import from FC

* Wed Oct 26 2022 Jakub Jelen <jjelen@redhat.com> - 1.2.0-1
- Official Fedora package (#2135713)

* Tue Apr 12 2022 Traxtopel <traxtopel@gmail.com> - 1.1.0-1
- Initial package.
